# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .user import User as User
from .model import Model as Model
from .secret import Secret as Secret
from .shared import (
    Choice as Choice,
    Status as Status,
    ChatMessage as ChatMessage,
    WandbConfig as WandbConfig,
    DeployedModel as DeployedModel,
    TrainingConfig as TrainingConfig,
    DeployedModelRef as DeployedModelRef,
    ChatCompletionTool as ChatCompletionTool,
    InferenceParameters as InferenceParameters,
    ChatCompletionMessageToolCall as ChatCompletionMessageToolCall,
    ChatCompletionMessageToolCallFunction as ChatCompletionMessageToolCallFunction,
)
from .account import Account as Account
from .api_key import APIKey as APIKey
from .dataset import Dataset as Dataset
from .dpo_job import DpoJob as DpoJob
from .splitted import Splitted as Splitted
from .auto_tune import AutoTune as AutoTune
from .placement import Placement as Placement
from .type_date import TypeDate as TypeDate
from .deployment import Deployment as Deployment
from .model_param import ModelParam as ModelParam
from .transformed import Transformed as Transformed
from .peft_details import PeftDetails as PeftDetails
from .api_key_param import APIKeyParam as APIKeyParam
from .dataset_param import DatasetParam as DatasetParam
from .splitted_param import SplittedParam as SplittedParam
from .auto_tune_param import AutoTuneParam as AutoTuneParam
from .lora_get_params import LoraGetParams as LoraGetParams
from .placement_param import PlacementParam as PlacementParam
from .type_date_param import TypeDateParam as TypeDateParam
from .user_get_params import UserGetParams as UserGetParams
from .completion_chunk import CompletionChunk as CompletionChunk
from .lora_list_params import LoraListParams as LoraListParams
from .lora_load_params import LoraLoadParams as LoraLoadParams
from .model_get_params import ModelGetParams as ModelGetParams
from .user_list_params import UserListParams as UserListParams
from .evaluation_result import EvaluationResult as EvaluationResult
from .model_list_params import ModelListParams as ModelListParams
from .secret_get_params import SecretGetParams as SecretGetParams
from .transformed_param import TransformedParam as TransformedParam
from .account_get_params import AccountGetParams as AccountGetParams
from .autoscaling_policy import AutoscalingPolicy as AutoscalingPolicy
from .base_model_details import BaseModelDetails as BaseModelDetails
from .dataset_get_params import DatasetGetParams as DatasetGetParams
from .dpo_job_get_params import DpoJobGetParams as DpoJobGetParams
from .lora_update_params import LoraUpdateParams as LoraUpdateParams
from .peft_details_param import PeftDetailsParam as PeftDetailsParam
from .secret_list_params import SecretListParams as SecretListParams
from .user_create_params import UserCreateParams as UserCreateParams
from .user_update_params import UserUpdateParams as UserUpdateParams
from .account_list_params import AccountListParams as AccountListParams
from .api_key_list_params import APIKeyListParams as APIKeyListParams
from .batch_inference_job import BatchInferenceJob as BatchInferenceJob
from .conversation_config import ConversationConfig as ConversationConfig
from .dataset_list_params import DatasetListParams as DatasetListParams
from .dpo_job_list_params import DpoJobListParams as DpoJobListParams
from .model_create_params import ModelCreateParams as ModelCreateParams
from .model_update_params import ModelUpdateParams as ModelUpdateParams
from .evaluator_get_params import EvaluatorGetParams as EvaluatorGetParams
from .model_prepare_params import ModelPrepareParams as ModelPrepareParams
from .secret_create_params import SecretCreateParams as SecretCreateParams
from .secret_update_params import SecretUpdateParams as SecretUpdateParams
from .api_key_create_params import APIKeyCreateParams as APIKeyCreateParams
from .api_key_delete_params import APIKeyDeleteParams as APIKeyDeleteParams
from .dataset_create_params import DatasetCreateParams as DatasetCreateParams
from .dataset_update_params import DatasetUpdateParams as DatasetUpdateParams
from .dataset_upload_params import DatasetUploadParams as DatasetUploadParams
from .deployment_get_params import DeploymentGetParams as DeploymentGetParams
from .dpo_job_create_params import DpoJobCreateParams as DpoJobCreateParams
from .evaluator_list_params import EvaluatorListParams as EvaluatorListParams
from .deployment_list_params import DeploymentListParams as DeploymentListParams
from .evaluator_get_response import EvaluatorGetResponse as EvaluatorGetResponse
from .dataset_upload_response import DatasetUploadResponse as DatasetUploadResponse
from .deployment_scale_params import DeploymentScaleParams as DeploymentScaleParams
from .evaluation_result_param import EvaluationResultParam as EvaluationResultParam
from .evaluator_list_response import EvaluatorListResponse as EvaluatorListResponse
from .autoscaling_policy_param import AutoscalingPolicyParam as AutoscalingPolicyParam
from .base_model_details_param import BaseModelDetailsParam as BaseModelDetailsParam
from .completion_create_params import CompletionCreateParams as CompletionCreateParams
from .deployment_create_params import DeploymentCreateParams as DeploymentCreateParams
from .deployment_delete_params import DeploymentDeleteParams as DeploymentDeleteParams
from .deployment_update_params import DeploymentUpdateParams as DeploymentUpdateParams
from .conversation_config_param import ConversationConfigParam as ConversationConfigParam
from .evaluation_job_get_params import EvaluationJobGetParams as EvaluationJobGetParams
from .completion_create_response import CompletionCreateResponse as CompletionCreateResponse
from .deployment_undelete_params import DeploymentUndeleteParams as DeploymentUndeleteParams
from .evaluation_job_list_params import EvaluationJobListParams as EvaluationJobListParams
from .supervised_fine_tuning_job import SupervisedFineTuningJob as SupervisedFineTuningJob
from .evaluation_job_get_response import EvaluationJobGetResponse as EvaluationJobGetResponse
from .evaluation_job_create_params import EvaluationJobCreateParams as EvaluationJobCreateParams
from .evaluation_job_list_response import EvaluationJobListResponse as EvaluationJobListResponse
from .model_validate_upload_params import ModelValidateUploadParams as ModelValidateUploadParams
from .reinforcement_fine_tuning_job import ReinforcementFineTuningJob as ReinforcementFineTuningJob
from .batch_inference_job_get_params import BatchInferenceJobGetParams as BatchInferenceJobGetParams
from .dataset_validate_upload_params import DatasetValidateUploadParams as DatasetValidateUploadParams
from .evaluation_job_create_response import EvaluationJobCreateResponse as EvaluationJobCreateResponse
from .reinforcement_fine_tuning_step import ReinforcementFineTuningStep as ReinforcementFineTuningStep
from .batch_inference_job_list_params import BatchInferenceJobListParams as BatchInferenceJobListParams
from .model_get_upload_endpoint_params import ModelGetUploadEndpointParams as ModelGetUploadEndpointParams
from .batch_inference_job_create_params import BatchInferenceJobCreateParams as BatchInferenceJobCreateParams
from .dataset_get_upload_endpoint_params import DatasetGetUploadEndpointParams as DatasetGetUploadEndpointParams
from .model_get_download_endpoint_params import ModelGetDownloadEndpointParams as ModelGetDownloadEndpointParams
from .model_get_upload_endpoint_response import ModelGetUploadEndpointResponse as ModelGetUploadEndpointResponse
from .deployment_shape_version_get_params import DeploymentShapeVersionGetParams as DeploymentShapeVersionGetParams
from .dataset_get_download_endpoint_params import DatasetGetDownloadEndpointParams as DatasetGetDownloadEndpointParams
from .dataset_get_upload_endpoint_response import DatasetGetUploadEndpointResponse as DatasetGetUploadEndpointResponse
from .deployment_shape_version_list_params import DeploymentShapeVersionListParams as DeploymentShapeVersionListParams
from .model_get_download_endpoint_response import ModelGetDownloadEndpointResponse as ModelGetDownloadEndpointResponse
from .deployment_shape_version_get_response import (
    DeploymentShapeVersionGetResponse as DeploymentShapeVersionGetResponse,
)
from .supervised_fine_tuning_job_get_params import SupervisedFineTuningJobGetParams as SupervisedFineTuningJobGetParams
from .dataset_get_download_endpoint_response import (
    DatasetGetDownloadEndpointResponse as DatasetGetDownloadEndpointResponse,
)
from .deployment_shape_version_list_response import (
    DeploymentShapeVersionListResponse as DeploymentShapeVersionListResponse,
)
from .supervised_fine_tuning_job_list_params import (
    SupervisedFineTuningJobListParams as SupervisedFineTuningJobListParams,
)
from .reinforcement_fine_tuning_job_get_params import (
    ReinforcementFineTuningJobGetParams as ReinforcementFineTuningJobGetParams,
)
from .supervised_fine_tuning_job_create_params import (
    SupervisedFineTuningJobCreateParams as SupervisedFineTuningJobCreateParams,
)
from .supervised_fine_tuning_job_resume_params import (
    SupervisedFineTuningJobResumeParams as SupervisedFineTuningJobResumeParams,
)
from .reinforcement_fine_tuning_job_list_params import (
    ReinforcementFineTuningJobListParams as ReinforcementFineTuningJobListParams,
)
from .reinforcement_fine_tuning_step_get_params import (
    ReinforcementFineTuningStepGetParams as ReinforcementFineTuningStepGetParams,
)
from .dpo_job_get_metrics_file_endpoint_response import (
    DpoJobGetMetricsFileEndpointResponse as DpoJobGetMetricsFileEndpointResponse,
)
from .reinforcement_fine_tuning_step_list_params import (
    ReinforcementFineTuningStepListParams as ReinforcementFineTuningStepListParams,
)
from .reinforcement_fine_tuning_job_cancel_params import (
    ReinforcementFineTuningJobCancelParams as ReinforcementFineTuningJobCancelParams,
)
from .reinforcement_fine_tuning_job_create_params import (
    ReinforcementFineTuningJobCreateParams as ReinforcementFineTuningJobCreateParams,
)
from .reinforcement_fine_tuning_job_resume_params import (
    ReinforcementFineTuningJobResumeParams as ReinforcementFineTuningJobResumeParams,
)
from .reinforcement_fine_tuning_step_create_params import (
    ReinforcementFineTuningStepCreateParams as ReinforcementFineTuningStepCreateParams,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import evaluation_job_get_params, evaluation_job_list_params, evaluation_job_create_params
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncCursorEvaluationJobs, AsyncCursorEvaluationJobs
from .._base_client import AsyncPaginator, make_request_options
from ..types.evaluation_job_get_response import EvaluationJobGetResponse
from ..types.evaluation_job_list_response import EvaluationJobListResponse
from ..types.evaluation_job_create_response import EvaluationJobCreateResponse

__all__ = ["EvaluationJobsResource", "AsyncEvaluationJobsResource"]


class EvaluationJobsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EvaluationJobsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return EvaluationJobsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EvaluationJobsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return EvaluationJobsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str | None = None,
        evaluation_job: evaluation_job_create_params.EvaluationJob,
        evaluation_job_id: str | Omit = omit,
        leaderboard_ids: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationJobCreateResponse:
        """
        Create Evaluation Job

        Args:
          leaderboard_ids: Optional leaderboards to attach this job to upon creation.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            f"/v1/accounts/{account_id}/evaluationJobs"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluationJobs",
            body=maybe_transform(
                {
                    "evaluation_job": evaluation_job,
                    "evaluation_job_id": evaluation_job_id,
                    "leaderboard_ids": leaderboard_ids,
                },
                evaluation_job_create_params.EvaluationJobCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationJobCreateResponse,
        )

    def list(
        self,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncCursorEvaluationJobs[EvaluationJobListResponse]:
        """
        List Evaluation Jobs

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            f"/v1/accounts/{account_id}/evaluationJobs"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluationJobs",
            page=SyncCursorEvaluationJobs[EvaluationJobListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    evaluation_job_list_params.EvaluationJobListParams,
                ),
            ),
            model=EvaluationJobListResponse,
        )

    def delete(
        self,
        evaluation_job_id: str,
        *,
        account_id: str | None = None,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Delete Evaluation Job

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluation_job_id:
            raise ValueError(f"Expected a non-empty value for `evaluation_job_id` but received {evaluation_job_id!r}")
        return self._delete(
            f"/v1/accounts/{account_id}/evaluationJobs/{evaluation_job_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluationJobs/{evaluation_job_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def get(
        self,
        evaluation_job_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationJobGetResponse:
        """Get Evaluation Job

        Args:
          read_mask: The fields to be returned in the response.

        If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluation_job_id:
            raise ValueError(f"Expected a non-empty value for `evaluation_job_id` but received {evaluation_job_id!r}")
        return self._get(
            f"/v1/accounts/{account_id}/evaluationJobs/{evaluation_job_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluationJobs/{evaluation_job_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"read_mask": read_mask}, evaluation_job_get_params.EvaluationJobGetParams),
            ),
            cast_to=EvaluationJobGetResponse,
        )


class AsyncEvaluationJobsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEvaluationJobsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncEvaluationJobsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEvaluationJobsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/fw-ai-external/python-sdk#with_streaming_response
        """
        return AsyncEvaluationJobsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str | None = None,
        evaluation_job: evaluation_job_create_params.EvaluationJob,
        evaluation_job_id: str | Omit = omit,
        leaderboard_ids: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationJobCreateResponse:
        """
        Create Evaluation Job

        Args:
          leaderboard_ids: Optional leaderboards to attach this job to upon creation.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            f"/v1/accounts/{account_id}/evaluationJobs"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluationJobs",
            body=await async_maybe_transform(
                {
                    "evaluation_job": evaluation_job,
                    "evaluation_job_id": evaluation_job_id,
                    "leaderboard_ids": leaderboard_ids,
                },
                evaluation_job_create_params.EvaluationJobCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationJobCreateResponse,
        )

    def list(
        self,
        *,
        account_id: str | None = None,
        filter: str | Omit = omit,
        order_by: str | Omit = omit,
        page_size: int | Omit = omit,
        page_token: str | Omit = omit,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[EvaluationJobListResponse, AsyncCursorEvaluationJobs[EvaluationJobListResponse]]:
        """
        List Evaluation Jobs

        Args:
          read_mask: The fields to be returned in the response. If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            f"/v1/accounts/{account_id}/evaluationJobs"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluationJobs",
            page=AsyncCursorEvaluationJobs[EvaluationJobListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "order_by": order_by,
                        "page_size": page_size,
                        "page_token": page_token,
                        "read_mask": read_mask,
                    },
                    evaluation_job_list_params.EvaluationJobListParams,
                ),
            ),
            model=EvaluationJobListResponse,
        )

    async def delete(
        self,
        evaluation_job_id: str,
        *,
        account_id: str | None = None,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Delete Evaluation Job

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluation_job_id:
            raise ValueError(f"Expected a non-empty value for `evaluation_job_id` but received {evaluation_job_id!r}")
        return await self._delete(
            f"/v1/accounts/{account_id}/evaluationJobs/{evaluation_job_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluationJobs/{evaluation_job_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def get(
        self,
        evaluation_job_id: str,
        *,
        account_id: str | None = None,
        read_mask: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EvaluationJobGetResponse:
        """Get Evaluation Job

        Args:
          read_mask: The fields to be returned in the response.

        If empty or "\\**", all fields will be
              returned.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id is None:
            account_id = self._client._get_account_id_path_param()
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not evaluation_job_id:
            raise ValueError(f"Expected a non-empty value for `evaluation_job_id` but received {evaluation_job_id!r}")
        return await self._get(
            f"/v1/accounts/{account_id}/evaluationJobs/{evaluation_job_id}"
            if self._client._base_url_overridden
            else f"https://api.fireworks.ai/v1/accounts/{account_id}/evaluationJobs/{evaluation_job_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"read_mask": read_mask}, evaluation_job_get_params.EvaluationJobGetParams
                ),
            ),
            cast_to=EvaluationJobGetResponse,
        )


class EvaluationJobsResourceWithRawResponse:
    def __init__(self, evaluation_jobs: EvaluationJobsResource) -> None:
        self._evaluation_jobs = evaluation_jobs

        self.create = to_raw_response_wrapper(
            evaluation_jobs.create,
        )
        self.list = to_raw_response_wrapper(
            evaluation_jobs.list,
        )
        self.delete = to_raw_response_wrapper(
            evaluation_jobs.delete,
        )
        self.get = to_raw_response_wrapper(
            evaluation_jobs.get,
        )


class AsyncEvaluationJobsResourceWithRawResponse:
    def __init__(self, evaluation_jobs: AsyncEvaluationJobsResource) -> None:
        self._evaluation_jobs = evaluation_jobs

        self.create = async_to_raw_response_wrapper(
            evaluation_jobs.create,
        )
        self.list = async_to_raw_response_wrapper(
            evaluation_jobs.list,
        )
        self.delete = async_to_raw_response_wrapper(
            evaluation_jobs.delete,
        )
        self.get = async_to_raw_response_wrapper(
            evaluation_jobs.get,
        )


class EvaluationJobsResourceWithStreamingResponse:
    def __init__(self, evaluation_jobs: EvaluationJobsResource) -> None:
        self._evaluation_jobs = evaluation_jobs

        self.create = to_streamed_response_wrapper(
            evaluation_jobs.create,
        )
        self.list = to_streamed_response_wrapper(
            evaluation_jobs.list,
        )
        self.delete = to_streamed_response_wrapper(
            evaluation_jobs.delete,
        )
        self.get = to_streamed_response_wrapper(
            evaluation_jobs.get,
        )


class AsyncEvaluationJobsResourceWithStreamingResponse:
    def __init__(self, evaluation_jobs: AsyncEvaluationJobsResource) -> None:
        self._evaluation_jobs = evaluation_jobs

        self.create = async_to_streamed_response_wrapper(
            evaluation_jobs.create,
        )
        self.list = async_to_streamed_response_wrapper(
            evaluation_jobs.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            evaluation_jobs.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            evaluation_jobs.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["BaseModelDetailsParam"]


class BaseModelDetailsParam(TypedDict, total=False):
    checkpoint_format: Annotated[
        Literal["CHECKPOINT_FORMAT_UNSPECIFIED", "NATIVE", "HUGGINGFACE"], PropertyInfo(alias="checkpointFormat")
    ]

    model_type: Annotated[str, PropertyInfo(alias="modelType")]
    """The type of the model."""

    moe: bool
    """If true, this is a Mixture of Experts (MoE) model.

    For serverless models, this affects the price per token.
    """

    parameter_count: Annotated[str, PropertyInfo(alias="parameterCount")]
    """The number of model parameters.

    For serverless models, this determines the price per token.
    """

    supports_fireattention: Annotated[bool, PropertyInfo(alias="supportsFireattention")]
    """Whether this model supports fireattention."""

    supports_mtp: Annotated[bool, PropertyInfo(alias="supportsMtp")]
    """If true, this model supports MTP."""

    tunable: bool
    """If true, this model is available for fine-tuning."""

    world_size: Annotated[int, PropertyInfo(alias="worldSize")]
    """
    The default number of GPUs the model is served with. If not specified, the
    default is 1.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo
from .auto_tune_param import AutoTuneParam
from .placement_param import PlacementParam
from .autoscaling_policy_param import AutoscalingPolicyParam

__all__ = ["DeploymentUpdateParams"]


class DeploymentUpdateParams(TypedDict, total=False):
    account_id: str

    base_model: Required[Annotated[str, PropertyInfo(alias="baseModel")]]

    accelerator_count: Annotated[int, PropertyInfo(alias="acceleratorCount")]
    """
    The number of accelerators used per replica. If not specified, the default is
    the estimated minimum required by the base model.
    """

    accelerator_type: Annotated[
        Literal[
            "ACCELERATOR_TYPE_UNSPECIFIED",
            "NVIDIA_A100_80GB",
            "NVIDIA_H100_80GB",
            "AMD_MI300X_192GB",
            "NVIDIA_A10G_24GB",
            "NVIDIA_A100_40GB",
            "NVIDIA_L4_24GB",
            "NVIDIA_H200_141GB",
            "NVIDIA_B200_180GB",
            "AMD_MI325X_256GB",
        ],
        PropertyInfo(alias="acceleratorType"),
    ]
    """The type of accelerator to use."""

    active_model_version: Annotated[str, PropertyInfo(alias="activeModelVersion")]
    """
    The model version that is currently active and applied to running replicas of a
    deployment.
    """

    autoscaling_policy: Annotated[AutoscalingPolicyParam, PropertyInfo(alias="autoscalingPolicy")]

    auto_tune: Annotated[AutoTuneParam, PropertyInfo(alias="autoTune")]
    """The performance profile to use for this deployment."""

    deployment_shape: Annotated[str, PropertyInfo(alias="deploymentShape")]
    """
    The name of the deployment shape that this deployment is using. On the server
    side, this will be replaced with the deployment shape version name.
    """

    deployment_template: Annotated[str, PropertyInfo(alias="deploymentTemplate")]
    """The name of the deployment template to use for this deployment.

    Only available to enterprise accounts.
    """

    description: str
    """Description of the deployment."""

    direct_route_api_keys: Annotated[SequenceNotStr[str], PropertyInfo(alias="directRouteApiKeys")]
    """The set of API keys used to access the direct route deployment.

    If direct routing is not enabled, this field is unused.
    """

    direct_route_type: Annotated[
        Literal["DIRECT_ROUTE_TYPE_UNSPECIFIED", "INTERNET", "GCP_PRIVATE_SERVICE_CONNECT", "AWS_PRIVATELINK"],
        PropertyInfo(alias="directRouteType"),
    ]
    """
    If set, this deployment will expose an endpoint that bypasses the Fireworks API
    gateway.
    """

    disable_deployment_size_validation: Annotated[bool, PropertyInfo(alias="disableDeploymentSizeValidation")]
    """Whether the deployment size validation is disabled."""

    display_name: Annotated[str, PropertyInfo(alias="displayName")]
    """Human-readable display name of the deployment.

    e.g. "My Deployment" Must be fewer than 64 characters long.
    """

    draft_model: Annotated[str, PropertyInfo(alias="draftModel")]
    """The draft model name for speculative decoding.

    e.g. accounts/fireworks/models/my-draft-model If empty, speculative decoding
    using a draft model is disabled. Default is the base model's
    default_draft_model. Set CreateDeploymentRequest.disable_speculative_decoding to
    false to disable this behavior.
    """

    draft_token_count: Annotated[int, PropertyInfo(alias="draftTokenCount")]
    """
    The number of candidate tokens to generate per step for speculative decoding.
    Default is the base model's draft_token_count. Set
    CreateDeploymentRequest.disable_speculative_decoding to false to disable this
    behavior.
    """

    enable_addons: Annotated[bool, PropertyInfo(alias="enableAddons")]
    """If true, PEFT addons are enabled for this deployment."""

    enable_hot_load: Annotated[bool, PropertyInfo(alias="enableHotLoad")]
    """Whether to use hot load for this deployment."""

    enable_hot_reload_latest_addon: Annotated[bool, PropertyInfo(alias="enableHotReloadLatestAddon")]
    """
    Allows up to 1 addon at a time to be loaded, and will merge it into the base
    model.
    """

    enable_mtp: Annotated[bool, PropertyInfo(alias="enableMtp")]
    """If true, MTP is enabled for this deployment."""

    enable_session_affinity: Annotated[bool, PropertyInfo(alias="enableSessionAffinity")]
    """
    Whether to apply sticky routing based on `user` field. Serverless will be set to
    true when creating deployment.
    """

    expire_time: Annotated[Union[str, datetime], PropertyInfo(alias="expireTime", format="iso8601")]
    """The time at which this deployment will automatically be deleted."""

    hot_load_bucket_type: Annotated[
        Literal["BUCKET_TYPE_UNSPECIFIED", "MINIO", "S3", "NEBIUS"], PropertyInfo(alias="hotLoadBucketType")
    ]

    max_replica_count: Annotated[int, PropertyInfo(alias="maxReplicaCount")]
    """
    The maximum number of replicas. If not specified, the default is
    max(min_replica_count, 1). May be set to 0 to downscale the deployment to 0.
    """

    min_replica_count: Annotated[int, PropertyInfo(alias="minReplicaCount")]
    """The minimum number of replicas. If not specified, the default is 0."""

    ngram_speculation_length: Annotated[int, PropertyInfo(alias="ngramSpeculationLength")]
    """The length of previous input sequence to be considered for N-gram speculation."""

    placement: PlacementParam
    """
    The desired geographic region where the deployment must be placed. If
    unspecified, the default is the GLOBAL multi-region.
    """

    precision: Literal[
        "PRECISION_UNSPECIFIED",
        "FP16",
        "FP8",
        "FP8_MM",
        "FP8_AR",
        "FP8_MM_KV_ATTN",
        "FP8_KV",
        "FP8_MM_V2",
        "FP8_V2",
        "FP8_MM_KV_ATTN_V2",
        "NF4",
        "FP4",
        "BF16",
        "FP4_BLOCKSCALED_MM",
        "FP4_MX_MOE",
    ]
    """The precision with which the model should be served."""

    target_model_version: Annotated[str, PropertyInfo(alias="targetModelVersion")]
    """
    The target model version that is being rolled out to the deployment. In a ready
    steady state, the target model version is the same as the active model version.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["DeploymentScaleParams"]


class DeploymentScaleParams(TypedDict, total=False):
    account_id: str

    replica_count: Annotated[int, PropertyInfo(alias="replicaCount")]
    """The desired number of replicas."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["ConversationConfig"]


class ConversationConfig(BaseModel):
    style: str
    """The chat template to use."""

    system: Optional[str] = None
    """The system prompt (if the chat style supports it)."""

    template: Optional[str] = None
    """The Jinja template (if style is "jinja")."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["AutoTune"]


class AutoTune(BaseModel):
    long_prompt: Optional[bool] = FieldInfo(alias="longPrompt", default=None)
    """If true, this deployment is optimized for long prompt lengths."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo
from .type_date_param import TypeDateParam
from .peft_details_param import PeftDetailsParam
from .base_model_details_param import BaseModelDetailsParam
from .conversation_config_param import ConversationConfigParam

__all__ = ["ModelUpdateParams"]


class ModelUpdateParams(TypedDict, total=False):
    account_id: str

    base_model_details: Annotated[BaseModelDetailsParam, PropertyInfo(alias="baseModelDetails")]
    """Base model details. Required if kind is HF_BASE_MODEL.

    Must not be set otherwise.
    """

    context_length: Annotated[int, PropertyInfo(alias="contextLength")]
    """The maximum context length supported by the model."""

    conversation_config: Annotated[ConversationConfigParam, PropertyInfo(alias="conversationConfig")]
    """If set, the Chat Completions API will be enabled for this model."""

    default_draft_model: Annotated[str, PropertyInfo(alias="defaultDraftModel")]
    """The default draft model to use when creating a deployment.

    If empty, speculative decoding is disabled by default.
    """

    default_draft_token_count: Annotated[int, PropertyInfo(alias="defaultDraftTokenCount")]
    """
    The default draft token count to use when creating a deployment. Must be
    specified if default_draft_model is specified.
    """

    deprecation_date: Annotated[TypeDateParam, PropertyInfo(alias="deprecationDate")]
    """
    If specified, this is the date when the serverless deployment of the model will
    be taken down.
    """

    description: str
    """The description of the model. Must be fewer than 1000 characters long."""

    display_name: Annotated[str, PropertyInfo(alias="displayName")]
    """Human-readable display name of the model.

    e.g. "My Model" Must be fewer than 64 characters long.
    """

    github_url: Annotated[str, PropertyInfo(alias="githubUrl")]
    """The URL to GitHub repository of the model."""

    hugging_face_url: Annotated[str, PropertyInfo(alias="huggingFaceUrl")]
    """The URL to the Hugging Face model."""

    kind: Literal[
        "KIND_UNSPECIFIED",
        "HF_BASE_MODEL",
        "HF_PEFT_ADDON",
        "HF_TEFT_ADDON",
        "FLUMINA_BASE_MODEL",
        "FLUMINA_ADDON",
        "DRAFT_ADDON",
        "FIRE_AGENT",
        "LIVE_MERGE",
        "CUSTOM_MODEL",
        "EMBEDDING_MODEL",
        "SNAPSHOT_MODEL",
    ]
    """The kind of model. If not specified, the default is HF_PEFT_ADDON."""

    peft_details: Annotated[PeftDetailsParam, PropertyInfo(alias="peftDetails")]
    """PEFT addon details. Required if kind is HF_PEFT_ADDON or HF_TEFT_ADDON."""

    public: bool
    """If true, the model will be publicly readable."""

    snapshot_type: Annotated[Literal["FULL_SNAPSHOT", "INCREMENTAL_SNAPSHOT"], PropertyInfo(alias="snapshotType")]

    supports_image_input: Annotated[bool, PropertyInfo(alias="supportsImageInput")]
    """If set, images can be provided as input to the model."""

    supports_lora: Annotated[bool, PropertyInfo(alias="supportsLora")]
    """Whether this model supports LoRA."""

    supports_tools: Annotated[bool, PropertyInfo(alias="supportsTools")]
    """If set, tools (i.e.

    functions) can be provided as input to the model, and the model may respond with
    one or more tool calls.
    """

    teft_details: Annotated[object, PropertyInfo(alias="teftDetails")]
    """TEFT addon details. Required if kind is HF_TEFT_ADDON.

    Must not be set otherwise.
    """

    training_context_length: Annotated[int, PropertyInfo(alias="trainingContextLength")]
    """The maximum context length supported by the model."""

    use_hf_apply_chat_template: Annotated[bool, PropertyInfo(alias="useHfApplyChatTemplate")]
    """
    If true, the model will use the Hugging Face apply_chat_template API to apply
    the chat template.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.status import Status
from .shared.wandb_config import WandbConfig
from .shared.training_config import TrainingConfig
from .shared.inference_parameters import InferenceParameters

__all__ = ["ReinforcementFineTuningJob"]


class ReinforcementFineTuningJob(BaseModel):
    dataset: str
    """The name of the dataset used for training."""

    evaluator: str
    """The evaluator resource name to use for RLOR fine-tuning job."""

    chunk_size: Optional[int] = FieldInfo(alias="chunkSize", default=None)
    """Data chunking for rollout, default size 200, enabled when dataset > 300.

    Valid range is 1-10,000.
    """

    completed_time: Optional[datetime] = FieldInfo(alias="completedTime", default=None)
    """The completed time for the reinforcement fine-tuning job."""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """The email address of the user who initiated this fine-tuning job."""

    create_time: Optional[datetime] = FieldInfo(alias="createTime", default=None)

    display_name: Optional[str] = FieldInfo(alias="displayName", default=None)

    eval_auto_carveout: Optional[bool] = FieldInfo(alias="evalAutoCarveout", default=None)
    """Whether to auto-carve the dataset for eval."""

    evaluation_dataset: Optional[str] = FieldInfo(alias="evaluationDataset", default=None)
    """The name of a separate dataset to use for evaluation."""

    inference_parameters: Optional[InferenceParameters] = FieldInfo(alias="inferenceParameters", default=None)
    """BIJ parameters."""

    mcp_server: Optional[str] = FieldInfo(alias="mcpServer", default=None)

    name: Optional[str] = None

    node_count: Optional[int] = FieldInfo(alias="nodeCount", default=None)
    """
    The number of nodes to use for the fine-tuning job. If not specified, the
    default is 1.
    """

    output_metrics: Optional[str] = FieldInfo(alias="outputMetrics", default=None)

    output_stats: Optional[str] = FieldInfo(alias="outputStats", default=None)
    """The output dataset's aggregated stats for the evaluation job."""

    state: Optional[
        Literal[
            "JOB_STATE_UNSPECIFIED",
            "JOB_STATE_CREATING",
            "JOB_STATE_RUNNING",
            "JOB_STATE_COMPLETED",
            "JOB_STATE_FAILED",
            "JOB_STATE_CANCELLED",
            "JOB_STATE_DELETING",
            "JOB_STATE_WRITING_RESULTS",
            "JOB_STATE_VALIDATING",
            "JOB_STATE_DELETING_CLEANING_UP",
            "JOB_STATE_PENDING",
            "JOB_STATE_EXPIRED",
            "JOB_STATE_RE_QUEUEING",
            "JOB_STATE_CREATING_INPUT_DATASET",
            "JOB_STATE_IDLE",
            "JOB_STATE_CANCELLING",
            "JOB_STATE_EARLY_STOPPED",
            "JOB_STATE_PAUSED",
        ]
    ] = None
    """JobState represents the state an asynchronous job can be in.

    - JOB_STATE_PAUSED: Job is paused, typically due to account suspension or manual
      intervention.
    """

    status: Optional[Status] = None

    training_config: Optional[TrainingConfig] = FieldInfo(alias="trainingConfig", default=None)
    """Common training configurations."""

    wandb_config: Optional[WandbConfig] = FieldInfo(alias="wandbConfig", default=None)
    """The Weights & Biases team/user account for logging training progress."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .chat_completion_chunk import ChatCompletionChunk as ChatCompletionChunk
from .completion_create_params import CompletionCreateParams as CompletionCreateParams
from .completion_create_response import CompletionCreateResponse as CompletionCreateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["TrainingConfig"]


class TrainingConfig(BaseModel):
    base_model: Optional[str] = FieldInfo(alias="baseModel", default=None)
    """
    The name of the base model to be fine-tuned Only one of 'base_model' or
    'warm_start_from' should be specified.
    """

    batch_size: Optional[int] = FieldInfo(alias="batchSize", default=None)
    """The maximum packed number of tokens per batch for training in sequence packing."""

    epochs: Optional[int] = None
    """The number of epochs to train for."""

    gradient_accumulation_steps: Optional[int] = FieldInfo(alias="gradientAccumulationSteps", default=None)

    jinja_template: Optional[str] = FieldInfo(alias="jinjaTemplate", default=None)

    learning_rate: Optional[float] = FieldInfo(alias="learningRate", default=None)
    """The learning rate used for training."""

    learning_rate_warmup_steps: Optional[int] = FieldInfo(alias="learningRateWarmupSteps", default=None)

    lora_rank: Optional[int] = FieldInfo(alias="loraRank", default=None)
    """The rank of the LoRA layers."""

    max_context_length: Optional[int] = FieldInfo(alias="maxContextLength", default=None)
    """The maximum context length to use with the model."""

    output_model: Optional[str] = FieldInfo(alias="outputModel", default=None)
    """The model ID to be assigned to the resulting fine-tuned model.

    If not specified, the job ID will be used.
    """

    region: Optional[
        Literal[
            "REGION_UNSPECIFIED",
            "US_IOWA_1",
            "US_VIRGINIA_1",
            "US_ILLINOIS_1",
            "AP_TOKYO_1",
            "US_ARIZONA_1",
            "US_TEXAS_1",
            "US_ILLINOIS_2",
            "EU_FRANKFURT_1",
            "US_TEXAS_2",
            "EU_ICELAND_1",
            "EU_ICELAND_2",
            "US_WASHINGTON_1",
            "US_WASHINGTON_2",
            "US_WASHINGTON_3",
            "AP_TOKYO_2",
            "US_CALIFORNIA_1",
            "US_UTAH_1",
            "US_GEORGIA_1",
            "US_GEORGIA_2",
            "US_WASHINGTON_4",
            "US_GEORGIA_3",
        ]
    ] = None
    """The region where the fine-tuning job is located."""

    warm_start_from: Optional[str] = FieldInfo(alias="warmStartFrom", default=None)
    """
    The PEFT addon model in Fireworks format to be fine-tuned from Only one of
    'base_model' or 'warm_start_from' should be specified.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["DatasetGetDownloadEndpointResponse"]


class DatasetGetDownloadEndpointResponse(BaseModel):
    filename_to_signed_urls: Optional[Dict[str, str]] = FieldInfo(alias="filenameToSignedUrls", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["AutoscalingPolicy"]


class AutoscalingPolicy(BaseModel):
    load_targets: Optional[Dict[str, float]] = FieldInfo(alias="loadTargets", default=None)

    scale_down_window: Optional[str] = FieldInfo(alias="scaleDownWindow", default=None)
    """
    The duration the autoscaler will wait before scaling down a deployment after
    observing decreased load. Default is 10m. Must be less than or equal to 1 hour.
    """

    scale_to_zero_window: Optional[str] = FieldInfo(alias="scaleToZeroWindow", default=None)
    """
    The duration after which there are no requests that the deployment will be
    scaled down to zero replicas, if min_replica_count==0. Default is 1h. This must
    be at least 5 minutes.
    """

    scale_up_window: Optional[str] = FieldInfo(alias="scaleUpWindow", default=None)
    """
    The duration the autoscaler will wait before scaling up a deployment after
    observing increased load. Default is 30s. Must be less than or equal to 1 hour.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Splitted"]


class Splitted(BaseModel):
    source_dataset_id: str = FieldInfo(alias="sourceDatasetId")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["PeftDetailsParam"]


class PeftDetailsParam(TypedDict, total=False):
    base_model: Required[Annotated[str, PropertyInfo(alias="baseModel")]]

    r: Required[int]
    """The rank of the update matrices. Must be between 4 and 64, inclusive."""

    target_modules: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="targetModules")]]

    merge_addon_model_name: Annotated[str, PropertyInfo(alias="mergeAddonModelName")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["DatasetUploadResponse"]


class DatasetUploadResponse(BaseModel):
    id: Optional[str] = None
    """The dataset id."""

    bytes: Optional[int] = None
    """The size of the file, in bytes."""

    created_at: Optional[int] = None
    """The Unix timestamp (in seconds) for when the file was created."""

    filename: Optional[str] = None
    """The name of the file."""

    object: Optional[str] = None
    """The object type, which is always file."""

    purpose: Optional[str] = None
    """The intended purpose of the file."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.status import Status

__all__ = ["EvaluatorListResponse", "Criterion", "CriterionCodeSnippets", "RollupSettings", "Source"]


class CriterionCodeSnippets(BaseModel):
    entry_file: Optional[str] = FieldInfo(alias="entryFile", default=None)

    entry_func: Optional[str] = FieldInfo(alias="entryFunc", default=None)

    file_contents: Optional[Dict[str, str]] = FieldInfo(alias="fileContents", default=None)

    language: Optional[str] = None


class Criterion(BaseModel):
    code_snippets: Optional[CriterionCodeSnippets] = FieldInfo(alias="codeSnippets", default=None)

    description: Optional[str] = None

    name: Optional[str] = None

    type: Optional[Literal["TYPE_UNSPECIFIED", "CODE_SNIPPETS"]] = None


class RollupSettings(BaseModel):
    """Strategy for metrics reports summary/rollup.
    e.g.

    {metric1: 1, metric2: 0.3}, rollup_settings could be criteria_weights: {metric1: 0.5, metric2: 0.5}, then final score will be 0.5 * 1 + 0.5 * 0.3 = 0.65
    If skip_rollup is true, the rollup step will be skipped since the criteria will also report the rollup score and metrics altogether.
    """

    criteria_weights: Optional[Dict[str, float]] = FieldInfo(alias="criteriaWeights", default=None)

    python_code: Optional[str] = FieldInfo(alias="pythonCode", default=None)

    skip_rollup: Optional[bool] = FieldInfo(alias="skipRollup", default=None)

    success_threshold: Optional[float] = FieldInfo(alias="successThreshold", default=None)


class Source(BaseModel):
    """Source information for the evaluator codebase."""

    github_repository_name: Optional[str] = FieldInfo(alias="githubRepositoryName", default=None)
    """Normalized GitHub repository name (e.g.

    owner/repository) when the source is GitHub.
    """

    type: Optional[Literal["TYPE_UNSPECIFIED", "TYPE_UPLOAD", "TYPE_GITHUB", "TYPE_TEMPORARY"]] = None
    """Identifies how the evaluator source code is provided."""


class EvaluatorListResponse(BaseModel):
    commit_hash: Optional[str] = FieldInfo(alias="commitHash", default=None)

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)

    create_time: Optional[datetime] = FieldInfo(alias="createTime", default=None)

    criteria: Optional[List[Criterion]] = None

    default_dataset: Optional[str] = FieldInfo(alias="defaultDataset", default=None)

    description: Optional[str] = None

    display_name: Optional[str] = FieldInfo(alias="displayName", default=None)

    entry_point: Optional[str] = FieldInfo(alias="entryPoint", default=None)

    multi_metrics: Optional[bool] = FieldInfo(alias="multiMetrics", default=None)
    """
    If true, the criteria will report multiple metric-score pairs Otherwise, each
    criteria will report the score assigned to the criteria name as metric.
    """

    name: Optional[str] = None

    requirements: Optional[str] = None

    rollup_settings: Optional[RollupSettings] = FieldInfo(alias="rollupSettings", default=None)
    """Strategy for metrics reports summary/rollup. e.g.

    {metric1: 1, metric2: 0.3}, rollup_settings could be criteria_weights: {metric1:
    0.5, metric2: 0.5}, then final score will be 0.5 _ 1 + 0.5 _ 0.3 = 0.65 If
    skip_rollup is true, the rollup step will be skipped since the criteria will
    also report the rollup score and metrics altogether.
    """

    source: Optional[Source] = None
    """Source information for the evaluator codebase."""

    state: Optional[Literal["STATE_UNSPECIFIED", "ACTIVE", "BUILDING", "BUILD_FAILED"]] = None

    status: Optional[Status] = None

    update_time: Optional[datetime] = FieldInfo(alias="updateTime", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["DeployedModelRef"]


class DeployedModelRef(BaseModel):
    default: Optional[bool] = None
    """
    If true, this is the default target when querying this model without the
    `#<deployment>` suffix. The first deployment a model is deployed to will have
    this field set to true automatically.
    """

    deployment: Optional[str] = None
    """The resource name of the base deployment the model is deployed to."""

    name: Optional[str] = None

    public: Optional[bool] = None
    """If true, the deployed model will be publicly reachable."""

    state: Optional[Literal["STATE_UNSPECIFIED", "UNDEPLOYING", "DEPLOYING", "DEPLOYED", "UPDATING"]] = None
    """The state of the deployed model."""
